==> nextcloud-30.0.12.tgz: nextcloud/apps/federation/l10n/hu.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Hozzáadva a megbízható kiszolgálók listájához",
    "Server is already in the list of trusted servers." : "A kiszolgáló már szerepel a megbízható kiszolgálók között.",
    "No server to federate with found" : "Nem található olyan kiszolgáló, amellyel föderálni lehetne",
    "Could not add server" : "A kiszolgáló nem adható hozzá",
    "Trusted servers" : "Megbízható kiszolgálók",
    "Federation" : "Föderáció",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "A föderáció lehetővé teszi a más megbízható kiszolgálókhoz kapcsolódást, hogy a kiszolgálók fiókjegyzéket cserélhessenek.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "A föderáció lehetővé teszi a más megbízható kiszolgálókhoz kapcsolódást, hogy a kiszolgálók fiókjegyzéket cseréljenek. Például ennek segítségével lesznek automatikusan kiegészítve a külső fióókok a föderált megosztásnál.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A föderáció lehetővé teszi a más megbízható kiszolgálókhoz kapcsolódást, hogy a kiszolgálók fiókjegyzéket cseréljenek. Például ennek segítségével lesznek automatikusan kiegészítve a külső fiókok a föderált megosztásnál. Nem szükséges egy kiszolgálót megbízhatóként hozzáadni ahhoz, hogy föderált megosztást hozzon létre.",
    "+ Add trusted server" : "+ Megbízható kiszolgáló hozzáadása",
    "Trusted server" : "Megbízható kiszolgáló",
    "Add" : "Hozzáadás"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3.tgz: nextcloud/apps/federation/l10n/hu.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Hozzáadva a megbízható kiszolgálók listájához",
    "No server found with ID: %s" : "Nem található kiszolgáló az azonosítóval: %s",
    "Could not remove server" : "Nem sikerült a kiszolgáló eltávolítása",
    "Server is already in the list of trusted servers." : "A kiszolgáló már szerepel a megbízható kiszolgálók között.",
    "No server to federate with found" : "Nem található olyan kiszolgáló, amellyel föderálni lehetne",
    "Could not add server" : "A kiszolgáló nem adható hozzá",
    "Trusted servers" : "Megbízható kiszolgálók",
    "Federation" : "Föderáció",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "A föderáció lehetővé teszi a más megbízható kiszolgálókhoz kapcsolódást, hogy a kiszolgálók fiókjegyzéket cserélhessenek.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "A föderáció lehetővé teszi a más megbízható kiszolgálókhoz kapcsolódást, hogy a kiszolgálók fiókjegyzéket cseréljenek. Például ennek segítségével lesznek automatikusan kiegészítve a külső fiókok a föderált megosztásnál.",
    "External documentation for Federated Cloud Sharing" : "Külső dokumentáció a föderált felhőmegosztáshoz",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A föderáció lehetővé teszi a más megbízható kiszolgálókhoz kapcsolódást, hogy a kiszolgálók fiókjegyzéket cseréljenek. Például ennek segítségével lesznek automatikusan kiegészítve a külső fiókok a föderált megosztásnál. Nem szükséges egy kiszolgálót megbízhatóként hozzáadni ahhoz, hogy föderált megosztást hozzon létre.",
    "Each server must validate the other. This process may require a few cron cycles." : "Minden kiszolgálónak ellenőriznie kell a másikat. Ez a folyat néhány cron ciklust vehet igénybe.",
    "+ Add trusted server" : "+ Megbízható kiszolgáló hozzáadása",
    "Trusted server" : "Megbízható kiszolgáló",
    "Add" : "Hozzáadás"
},
"nplurals=2; plural=(n != 1);");
